@@ -76,6 +76,10 @@ func (Pipe) Default(ctx *context.Context) error {
 		if archive.ID == "" {
 			archive.ID = "default"
 		}
+		if len(archive.Builds) > 0 {
+			deprecate.Notice(ctx, "archives.builds")
+			archive.IDs = append(archive.IDs, archive.Builds...)
+		}
 		if len(archive.Files) == 0 {
 			archive.Files = []config.File{
 				{Source: "license*", Default: true},
@@ -92,6 +96,7 @@ func (Pipe) Default(ctx *context.Context) error {
 				archive.NameTemplate = defaultBinaryNameTemplate
 			}
 		}
+		archive.BuildsInfo.Mode = 0o755
 		ids.Inc(archive.ID)
 	}
 	return ids.Validate()
@@ -117,8 +122,8 @@ func (Pipe) Run(ctx *context.Context) error {
 			artifact.ByType(artifact.CArchive),
 			artifact.ByType(artifact.CShared),
 		)}
-		if len(archive.Builds) > 0 {
-			filter = append(filter, artifact.ByIDs(archive.Builds...))
+		if len(archive.IDs) > 0 {
+			filter = append(filter, artifact.ByIDs(archive.IDs...))
 		}
 
 		isBinary := slices.Contains(archive.Formats, "binary")
@@ -236,7 +241,7 @@ func create(ctx *context.Context, arch config.Archive, binaries []*artifact.Arti
 		Type: artifact.UploadableArchive,
 		Name: folder + "." + format,
 		Path: archivePath,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID:        arch.ID,
 			artifact.ExtraFormat:    format,
 			artifact.ExtraWrappedIn: wrap,
@@ -254,7 +259,9 @@ func create(ctx *context.Context, arch config.Archive, binaries []*artifact.Arti
 		art.Goppc64 = binaries[0].Goppc64
 		art.Goriscv64 = binaries[0].Goriscv64
 		art.Target = binaries[0].Target
-		art.Extra[artifact.ExtraReplaces] = binaries[0].Extra[artifact.ExtraReplaces]
+		if rep, ok := binaries[0].Extra[artifact.ExtraReplaces]; ok {
+			art.Extra[artifact.ExtraReplaces] = rep
+		}
 	}
 
 	ctx.Artifacts.Add(art)
@@ -278,11 +285,12 @@ func skip(ctx *context.Context, archive config.Archive, binaries []*artifact.Art
 		if err != nil {
 			return err
 		}
-		finalName := name + artifact.ExtraOr(*binary, artifact.ExtraExt, "")
+		finalName := name + binary.Ext()
 		log.WithField("binary", binary.Name).
 			WithField("name", finalName).
 			Info("archiving")
-		ctx.Artifacts.Add(&artifact.Artifact{
+
+		art := &artifact.Artifact{
 			Type:      artifact.UploadableBinary,
 			Name:      finalName,
 			Path:      binary.Path,
@@ -296,13 +304,16 @@ func skip(ctx *context.Context, archive config.Archive, binaries []*artifact.Art
 			Goppc64:   binary.Goppc64,
 			Goriscv64: binary.Goriscv64,
 			Target:    binary.Target,
-			Extra: map[string]interface{}{
-				artifact.ExtraID:       archive.ID,
-				artifact.ExtraFormat:   archive.Format,
-				artifact.ExtraBinary:   binary.Name,
-				artifact.ExtraReplaces: binaries[0].Extra[artifact.ExtraReplaces],
+			Extra: map[string]any{
+				artifact.ExtraID:     archive.ID,
+				artifact.ExtraFormat: "binary",
+				artifact.ExtraBinary: binary.Name,
 			},
-		})
+		}
+		if rep, ok := binaries[0].Extra[artifact.ExtraReplaces]; ok {
+			art.Extra[artifact.ExtraReplaces] = rep
+		}
+		ctx.Artifacts.Add(art)
 	}
 	return nil
 }
