@@ -146,11 +146,11 @@ func doRun(ctx *context.Context, aur config.AUR, cl client.ReleaseURLTemplater)
 		switch art.Type {
 		case artifact.UploadableBinary:
 			name := art.Name
-			bin := artifact.ExtraOr(*art, artifact.ExtraBinary, art.Name)
+			bin := artifact.MustExtra[string](*art, artifact.ExtraBinary)
 			pkg = fmt.Sprintf(`install -Dm755 "./%s "${pkgdir}/usr/bin/%s"`, name, bin)
 		case artifact.UploadableArchive:
 			folder := artifact.ExtraOr(*art, artifact.ExtraWrappedIn, ".")
-			for _, bin := range artifact.ExtraOr(*art, artifact.ExtraBinaries, []string{}) {
+			for _, bin := range artifact.MustExtra[[]string](*art, artifact.ExtraBinaries) {
 				path := filepath.ToSlash(filepath.Clean(filepath.Join(folder, bin)))
 				pkg = fmt.Sprintf(`install -Dm755 "./%s" "${pkgdir}/usr/bin/%s"`, path, bin)
 				break
@@ -195,7 +195,7 @@ func doRun(ctx *context.Context, aur config.AUR, cl client.ReleaseURLTemplater)
 			Name: info.name,
 			Path: path,
 			Type: info.kind,
-			Extra: map[string]interface{}{
+			Extra: map[string]any{
 				aurExtra:         aur,
 				artifact.ExtraID: aur.Name,
 			},
@@ -345,7 +345,7 @@ func dataFor(ctx *context.Context, cfg config.AUR, cl client.ReleaseURLTemplater
 			DownloadURL: url,
 			SHA256:      sum,
 			Arch:        toPkgBuildArch(art.Goarch + art.Goarm),
-			Format:      artifact.ExtraOr(*art, artifact.ExtraFormat, ""),
+			Format:      art.Format(),
 		}
 		result.ReleasePackages = append(result.ReleasePackages, releasePackage)
 		result.Arches = append(result.Arches, releasePackage.Arch)
@@ -380,11 +380,7 @@ func (Pipe) Publish(ctx *context.Context) error {
 }
 
 func doPublish(ctx *context.Context, pkgs []*artifact.Artifact) error {
-	cfg, err := artifact.Extra[config.AUR](*pkgs[0], aurExtra)
-	if err != nil {
-		return err
-	}
-
+	cfg := artifact.MustExtra[config.AUR](*pkgs[0], aurExtra)
 	if strings.TrimSpace(cfg.SkipUpload) == "true" {
 		return pipe.Skip("aur.skip_upload is set")
 	}
