@@ -1,7 +1,6 @@
 package before
 
 import (
-	"os"
 	"path/filepath"
 	"testing"
 
@@ -15,9 +14,8 @@ import (
 
 func TestMain(m *testing.M) {
 	log.SetLevel(log.DebugLevel)
-	code := m.Run()
+	m.Run()
 	log.SetLevel(log.InfoLevel)
-	os.Exit(code)
 }
 
 func TestDescription(t *testing.T) {
@@ -25,13 +23,16 @@ func TestDescription(t *testing.T) {
 }
 
 func TestRunPipe(t *testing.T) {
-	for _, tc := range [][]string{
+	table := [][]string{
 		nil,
 		{},
 		{"go version"},
 		{"go version", "go list"},
-		{`bash -c "go version; echo \"lala spaces and such\""`},
-	} {
+	}
+	if testlib.InPath("bash") {
+		table = append(table, []string{`bash -c "go version; echo \"lala spaces and such\""`})
+	}
+	for _, tc := range table {
 		ctx := testctx.NewWithCfg(
 			config.Project{
 				Before: config.Before{
@@ -79,7 +80,7 @@ func TestRunWithEnv(t *testing.T) {
 				"TEST_FILE=" + f,
 			},
 			Before: config.Before{
-				Hooks: []string{"touch {{ .Env.TEST_FILE }}"},
+				Hooks: []string{testlib.Touch("{{ .Env.TEST_FILE }}")},
 			},
 		},
 	)))
@@ -90,7 +91,7 @@ func TestInvalidTemplate(t *testing.T) {
 	testlib.RequireTemplateError(t, Pipe{}.Run(testctx.NewWithCfg(
 		config.Project{
 			Before: config.Before{
-				Hooks: []string{"touch {{ .fasdsd }"},
+				Hooks: []string{"doesnt-matter {{ .fasdsd }"},
 			},
 		},
 	)))
