@@ -3,6 +3,7 @@ package brew
 import (
 	"bufio"
 	"bytes"
+	"cmp"
 	"errors"
 	"fmt"
 	"maps"
@@ -10,7 +11,6 @@ import (
 	"path"
 	"path/filepath"
 	"slices"
-	"sort"
 	"strings"
 	"text/template"
 
@@ -121,11 +121,7 @@ func publishAll(ctx *context.Context, cli client.Client) error {
 }
 
 func doPublish(ctx *context.Context, formula *artifact.Artifact, cl client.Client) error {
-	brew, err := artifact.Extra[config.Homebrew](*formula, brewConfigExtra)
-	if err != nil {
-		return err
-	}
-
+	brew := artifact.MustExtra[config.Homebrew](*formula, brewConfigExtra)
 	if strings.TrimSpace(brew.SkipUpload) == "true" {
 		return pipe.Skip("brew.skip_upload is set")
 	}
@@ -277,7 +273,7 @@ func doRun(ctx *context.Context, brew config.Homebrew, cl client.ReleaseURLTempl
 		Name: filename,
 		Path: path,
 		Type: artifact.BrewTap,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			brewConfigExtra: brew,
 		},
 	})
@@ -301,7 +297,7 @@ func doBuildFormula(ctx *context.Context, data templateData) (string, error) {
 	t := template.New("cask.rb")
 	var err error
 	t, err = t.Funcs(map[string]any{
-		"include": func(name string, data interface{}) (string, error) {
+		"include": func(name string, data any) (string, error) {
 			buf := bytes.NewBuffer(nil)
 			if err := t.ExecuteTemplate(buf, name, data); err != nil {
 				return "", err
@@ -371,10 +367,10 @@ func installs(ctx *context.Context, cfg config.Homebrew, art *artifact.Artifact)
 	switch art.Type {
 	case artifact.UploadableBinary:
 		name := art.Name
-		bin := artifact.ExtraOr(*art, artifact.ExtraBinary, art.Name)
+		bin := artifact.MustExtra[string](*art, artifact.ExtraBinary)
 		installMap[fmt.Sprintf("bin.install %q => %q", name, bin)] = true
 	case artifact.UploadableArchive:
-		for _, bin := range artifact.ExtraOr(*art, artifact.ExtraBinaries, []string{}) {
+		for _, bin := range artifact.MustExtra[[]string](*art, artifact.ExtraBinaries) {
 			installMap[fmt.Sprintf("bin.install %q", bin)] = true
 		}
 	}
@@ -386,8 +382,8 @@ func installs(ctx *context.Context, cfg config.Homebrew, art *artifact.Artifact)
 }
 
 func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.ReleaseURLTemplater, artifacts []*artifact.Artifact) (templateData, error) {
-	sort.Slice(cfg.Dependencies, func(i, j int) bool {
-		return cfg.Dependencies[i].Name < cfg.Dependencies[j].Name
+	slices.SortFunc(cfg.Dependencies, func(a, b config.HomebrewDependency) int {
+		return cmp.Compare(a.Name, b.Name)
 	})
 	result := templateData{
 		Name:          formulaNameFor(cfg.Name),
@@ -460,13 +456,13 @@ func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.ReleaseURLTemp
 		result.HasOnlyAmd64MacOsPkg = true
 	}
 
-	sort.Slice(result.LinuxPackages, lessFnFor(result.LinuxPackages))
-	sort.Slice(result.MacOSPackages, lessFnFor(result.MacOSPackages))
+	slices.SortStableFunc(result.LinuxPackages, compareByArch)
+	slices.SortStableFunc(result.MacOSPackages, compareByArch)
 	return result, nil
 }
 
-func lessFnFor(list []releasePackage) func(i, j int) bool {
-	return func(i, j int) bool { return list[i].Arch < list[j].Arch }
+func compareByArch(a, b releasePackage) int {
+	return cmp.Compare(a.Arch, b.Arch)
 }
 
 func split(s string) []string {
@@ -481,7 +477,7 @@ func split(s string) []string {
 // that more resembles a valid Ruby class name
 // e.g. foo_bar@v6.0.0-rc is turned into FooBarATv6_0_0RC
 //
-// This function must match the behavior of Homewbrews's Formulary.class_s function:
+// This function must match the behavior of Homebrew's Formulary.class_s function:
 //
 //	<https://github.com/Homebrew/brew/blob/587949bd8417c486795be04194f9e9baeaa9f5a7/Library/Homebrew/formulary.rb#L522-L528>
 func formulaNameFor(name string) string {
