@@ -5,12 +5,13 @@
 package krew
 
 import (
+	"cmp"
 	"errors"
 	"fmt"
 	"os"
 	"path"
 	"path/filepath"
-	"sort"
+	"slices"
 	"strings"
 
 	"github.com/caarlos0/log"
@@ -143,7 +144,7 @@ func doRun(ctx *context.Context, krew config.Krew, cl client.ReleaseURLTemplater
 		Name: filename,
 		Path: yamlPath,
 		Type: artifact.KrewPluginManifest,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			krewConfigExtra: krew,
 		},
 	})
@@ -233,7 +234,7 @@ func manifestFor(
 		}
 
 		for _, arch := range goarch {
-			bins := artifact.ExtraOr(*art, artifact.ExtraBinaries, []string{})
+			bins := artifact.MustExtra[[]string](*art, artifact.ExtraBinaries)
 			if len(bins) != 1 {
 				return result, fmt.Errorf("krew: only one binary per archive allowed, got %d on %q", len(bins), art.Name)
 			}
@@ -251,8 +252,8 @@ func manifestFor(
 		}
 	}
 
-	sort.Slice(result.Spec.Platforms, func(i, j int) bool {
-		return result.Spec.Platforms[i].URI > result.Spec.Platforms[j].URI
+	slices.SortFunc(result.Spec.Platforms, func(a, b Platform) int {
+		return -cmp.Compare(a.URI, b.URI)
 	})
 
 	return result, nil
@@ -283,11 +284,7 @@ func publishAll(ctx *context.Context, cli client.Client) error {
 }
 
 func doPublish(ctx *context.Context, manifest *artifact.Artifact, cl client.Client) error {
-	cfg, err := artifact.Extra[config.Krew](*manifest, krewConfigExtra)
-	if err != nil {
-		return err
-	}
-
+	cfg := artifact.MustExtra[config.Krew](*manifest, krewConfigExtra)
 	if strings.TrimSpace(cfg.SkipUpload) == "true" {
 		return pipe.Skip("krews.skip_upload is set")
 	}
