@@ -1,8 +1,10 @@
+// Package nix creates nix packages.
 package nix
 
 import (
 	"bufio"
 	"bytes"
+	"cmp"
 	"errors"
 	"fmt"
 	"maps"
@@ -18,6 +20,7 @@ import (
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
 	"github.com/goreleaser/goreleaser/v2/internal/client"
 	"github.com/goreleaser/goreleaser/v2/internal/commitauthor"
+	"github.com/goreleaser/goreleaser/v2/internal/experimental"
 	"github.com/goreleaser/goreleaser/v2/internal/pipe"
 	"github.com/goreleaser/goreleaser/v2/internal/skips"
 	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
@@ -49,25 +52,23 @@ var (
 
 // NewBuild returns a pipe to be used in the build phase.
 func NewBuild() Pipe {
-	return Pipe{buildShaPrefetcher{}}
+	return Pipe{zeroHasher}
 }
 
 // NewPublish returns a pipe to be used in the publish phase.
 func NewPublish() Pipe {
-	return Pipe{publishShaPrefetcher{
-		bin: nixPrefetchURLBin,
-	}}
+	return Pipe{realHasher}
 }
 
 type Pipe struct {
-	prefetcher shaPrefetcher
+	hasher fileHasher
 }
 
 func (Pipe) String() string                           { return "nixpkgs" }
 func (Pipe) ContinueOnError() bool                    { return true }
-func (Pipe) Dependencies(_ *context.Context) []string { return []string{"nix-prefetch-url"} }
+func (Pipe) Dependencies(_ *context.Context) []string { return []string{"nix-hash"} }
 func (p Pipe) Skip(ctx *context.Context) bool {
-	return skips.Any(ctx, skips.Nix) || len(ctx.Config.Nix) == 0 || !p.prefetcher.Available()
+	return skips.Any(ctx, skips.Nix) || len(ctx.Config.Nix) == 0 || !p.hasher.Available()
 }
 
 func (Pipe) Default(ctx *context.Context) error {
@@ -124,7 +125,7 @@ func (p Pipe) runAll(ctx *context.Context, cli client.ReleaseURLTemplater) error
 func (p Pipe) publishAll(ctx *context.Context, cli client.Client) error {
 	skips := pipe.SkipMemento{}
 	for _, nix := range ctx.Artifacts.Filter(artifact.ByType(artifact.Nixpkg)).List() {
-		err := doPublish(ctx, p.prefetcher, cli, nix)
+		err := doPublish(ctx, p.hasher, cli, nix)
 		if err != nil && pipe.IsSkip(err) {
 			skips.Remember(err)
 			continue
@@ -168,7 +169,7 @@ func (p Pipe) doRun(ctx *context.Context, nix config.Nix, cl client.ReleaseURLTe
 		return err
 	}
 
-	content, err := preparePkg(ctx, nix, cl, p.prefetcher)
+	content, err := preparePkg(ctx, nix, cl, p.hasher)
 	if err != nil {
 		return err
 	}
@@ -182,7 +183,7 @@ func (p Pipe) doRun(ctx *context.Context, nix config.Nix, cl client.ReleaseURLTe
 		Name: filepath.Base(path),
 		Path: path,
 		Type: artifact.Nixpkg,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			nixConfigExtra: nix,
 		},
 	})
@@ -194,7 +195,7 @@ func preparePkg(
 	ctx *context.Context,
 	nix config.Nix,
 	cli client.ReleaseURLTemplater,
-	prefetcher shaPrefetcher,
+	hasher fileHasher,
 ) (string, error) {
 	filters := []artifact.Filter{
 		artifact.Or(
@@ -283,11 +284,11 @@ func preparePkg(
 
 	platforms := map[string]bool{}
 	for _, art := range archives {
-		url, err := tmpl.New(ctx).WithArtifact(art).Apply(nix.URLTemplate)
+		sha, err := hasher.Hash(art.Path)
 		if err != nil {
 			return "", err
 		}
-		sha, err := prefetcher.Prefetch(url)
+		url, err := tmpl.New(ctx).WithArtifact(art).Apply(nix.URLTemplate)
 		if err != nil {
 			return "", err
 		}
@@ -301,13 +302,13 @@ func preparePkg(
 			if _, ok := data.Archives[key]; ok {
 				return "", ErrMultipleArchivesSamePlatform
 			}
-			folder := artifact.ExtraOr(*art, artifact.ExtraWrappedIn, ".")
-			if folder == "" {
-				folder = "."
-			}
+			folder := cmp.Or(artifact.ExtraOr(*art, artifact.ExtraWrappedIn, ""), ".")
 			data.SourceRoots[key] = folder
 			data.Archives[key] = archive
 			plat := goosToPlatform[art.Goos+goarch+art.Goarm]
+			if plat == "" {
+				return "", errors.New("invalid platform: " + art.Goos + goarch + art.Goarm)
+			}
 			platforms[plat] = true
 		}
 	}
@@ -330,6 +331,7 @@ func expandGoarch(goarch string) []string {
 var goosToPlatform = map[string]string{
 	"linuxamd64":  "x86_64-linux",
 	"linuxarm64":  "aarch64-linux",
+	"linuxarm":    "armv" + experimental.DefaultGOARM() + "l-linux",
 	"linuxarm6":   "armv6l-linux",
 	"linuxarm7":   "armv7l-linux",
 	"linux386":    "i686-linux",
@@ -337,12 +339,8 @@ var goosToPlatform = map[string]string{
 	"darwinarm64": "aarch64-darwin",
 }
 
-func doPublish(ctx *context.Context, prefetcher shaPrefetcher, cl client.Client, pkg *artifact.Artifact) error {
-	nix, err := artifact.Extra[config.Nix](*pkg, nixConfigExtra)
-	if err != nil {
-		return err
-	}
-
+func doPublish(ctx *context.Context, hasher fileHasher, cl client.Client, pkg *artifact.Artifact) error {
+	nix := artifact.MustExtra[config.Nix](*pkg, nixConfigExtra)
 	if strings.TrimSpace(nix.SkipUpload) == "true" {
 		return errSkipUpload
 	}
@@ -365,7 +363,7 @@ func doPublish(ctx *context.Context, prefetcher shaPrefetcher, cl client.Client,
 		return err
 	}
 
-	content, err := preparePkg(ctx, nix, cl, prefetcher)
+	content, err := preparePkg(ctx, nix, cl, hasher)
 	if err != nil {
 		return err
 	}
@@ -473,7 +471,7 @@ func installs(ctx *context.Context, nix config.Nix, art *artifact.Artifact) ([]s
 
 	result := []string{"mkdir -p $out/bin"}
 	binInstallFormat := binInstallFormats(nix)
-	for _, bin := range artifact.ExtraOr(*art, artifact.ExtraBinaries, []string{}) {
+	for _, bin := range artifact.MustExtra[[]string](*art, artifact.ExtraBinaries) {
 		for _, format := range binInstallFormat {
 			result = append(result, fmt.Sprintf(format, bin))
 		}
@@ -523,7 +521,7 @@ func binInstallFormats(nix config.Nix) []string {
 
 func split(s string) []string {
 	var result []string
-	for _, line := range strings.Split(strings.TrimSpace(s), "\n") {
+	for line := range strings.SplitSeq(strings.TrimSpace(s), "\n") {
 		line := strings.TrimSpace(line)
 		if line == "" {
 			continue
@@ -541,26 +539,29 @@ func depNames(deps []config.NixDependency) []string {
 	return result
 }
 
-type shaPrefetcher interface {
-	Prefetch(url string) (string, error)
+type fileHasher interface {
+	Hash(name string) (string, error)
 	Available() bool
 }
 
 const (
-	zeroHash          = "0000000000000000000000000000000000000000000000000000"
-	nixPrefetchURLBin = "nix-prefetch-url"
+	zeroHash   = "0000000000000000000000000000000000000000000000000000"
+	nixHashBin = "nix-hash"
 )
 
-type buildShaPrefetcher struct{}
+var (
+	zeroHasher fileHasher = alwaysZeroHasher{}
+	realHasher fileHasher = nixHasher{bin: nixHashBin}
+)
 
-func (buildShaPrefetcher) Prefetch(_ string) (string, error) { return zeroHash, nil }
-func (buildShaPrefetcher) Available() bool                   { return true }
+type alwaysZeroHasher struct{}
 
-type publishShaPrefetcher struct {
-	bin string
-}
+func (alwaysZeroHasher) Hash(string) (string, error) { return zeroHash, nil }
+func (alwaysZeroHasher) Available() bool             { return true }
 
-func (p publishShaPrefetcher) Available() bool {
+type nixHasher struct{ bin string }
+
+func (p nixHasher) Available() bool {
 	_, err := exec.LookPath(p.bin)
 	if err != nil {
 		log.Warnf("%s is not available", p.bin)
@@ -568,11 +569,18 @@ func (p publishShaPrefetcher) Available() bool {
 	return err == nil
 }
 
-func (p publishShaPrefetcher) Prefetch(url string) (string, error) {
-	out, err := exec.Command(p.bin, url).Output()
+func (p nixHasher) Hash(name string) (string, error) {
+	// $ nix-hash --type sha256 --flat --base32 <(echo test)
+	out, err := exec.Command(
+		p.bin,
+		"--type", "sha256",
+		"--flat",
+		"--base32",
+		name,
+	).Output()
 	outStr := strings.TrimSpace(string(out))
 	if err != nil {
-		return "", fmt.Errorf("could not prefetch url: %s: %w: %s", url, err, outStr)
+		return "", fmt.Errorf("could not hash file: %s: %w: %s", name, err, outStr)
 	}
 	return outStr, nil
 }
