@@ -1,7 +1,9 @@
+// Package sbom creates a Software Bill of Materials (SBOM) for each artifact.
 package sbom
 
 import (
 	"bytes"
+	"errors"
 	"fmt"
 	"io"
 	"os"
@@ -234,7 +236,7 @@ func catalogArtifact(ctx *context.Context, cfg config.SBOM, a *artifact.Artifact
 				Type: artifact.SBOM,
 				Name: filepath.Base(path),
 				Path: match,
-				Extra: map[string]interface{}{
+				Extra: map[string]any{
 					artifact.ExtraID: cfg.ID,
 				},
 			})
@@ -242,7 +244,7 @@ func catalogArtifact(ctx *context.Context, cfg config.SBOM, a *artifact.Artifact
 	}
 
 	if len(artifacts) == 0 {
-		return nil, fmt.Errorf("cataloging artifacts: command did not write any files, check your configuration")
+		return nil, errors.New("cataloging artifacts: command did not write any files, check your configuration")
 	}
 
 	return artifacts, nil
