@@ -5,14 +5,14 @@ import (
 	"path/filepath"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/golden"
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/testctx"
-	"github.com/goreleaser/goreleaser/internal/testlib"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/client"
+	"github.com/goreleaser/goreleaser/v2/internal/golden"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/testctx"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/stretchr/testify/require"
 )
 
@@ -48,33 +48,9 @@ func TestDefault(t *testing.T) {
 	require.NotEmpty(t, ctx.Config.Scoops[0].CommitMessageTemplate)
 }
 
-func TestDefaultDeprecated(t *testing.T) {
-	testlib.Mktmp(t)
-
-	ctx := testctx.NewWithCfg(
-		config.Project{
-			ProjectName: "barr",
-			Scoop: config.Scoop{
-				Bucket: config.RepoRef{
-					Name: "foo",
-				},
-			},
-		},
-		testctx.GitHubTokenType,
-	)
-	require.NoError(t, Pipe{}.Default(ctx))
-	require.Len(t, ctx.Config.Scoops, 1)
-	require.Equal(t, ctx.Config.ProjectName, ctx.Config.Scoops[0].Name)
-	require.NotEmpty(t, ctx.Config.Scoops[0].CommitAuthor.Name)
-	require.NotEmpty(t, ctx.Config.Scoops[0].CommitAuthor.Email)
-	require.NotEmpty(t, ctx.Config.Scoops[0].CommitMessageTemplate)
-	require.Equal(t, "foo", ctx.Config.Scoops[0].Repository.Name)
-	require.True(t, ctx.Deprecated)
-}
-
 func Test_doRun(t *testing.T) {
-	folder := t.TempDir()
-	file := filepath.Join(folder, "archive")
+	directory := t.TempDir()
+	file := filepath.Join(directory, "archive")
 	require.NoError(t, os.WriteFile(file, []byte("lorem ipsum"), 0o644))
 
 	type args struct {
@@ -119,7 +95,7 @@ func Test_doRun(t *testing.T) {
 								Owner: "test",
 								Name:  "test",
 							},
-							Folder:      "scoops",
+							Directory:   "scoops",
 							Description: "A run pipe test formula",
 							Homepage:    "https://github.com/goreleaser",
 						}},
@@ -162,7 +138,7 @@ func Test_doRun(t *testing.T) {
 								Name:  "test",
 							},
 							IDs:         []string{"id2"},
-							Folder:      "scoops",
+							Directory:   "scoops",
 							Description: "A run pipe test formula",
 							Homepage:    "https://github.com/goreleaser",
 						}},
@@ -174,14 +150,28 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file, Extra: map[string]any{
-					artifact.ExtraID:       "id1",
-					artifact.ExtraBinaries: []string{"bin1", "bin2"},
-				}},
-				{Name: "foos_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file, Extra: map[string]any{
-					artifact.ExtraID:       "id2",
-					artifact.ExtraBinaries: []string{"bin4", "bin3"},
-				}},
+				{
+					Name:    "foo_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraID:       "id1",
+						artifact.ExtraBinaries: []string{"bin1", "bin2"},
+					},
+				},
+				{
+					Name:    "foos_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraID:       "id2",
+						artifact.ExtraBinaries: []string{"bin4", "bin3"},
+					},
+				},
 			},
 			shouldNotErr,
 			shouldNotErr,
@@ -198,14 +188,16 @@ func Test_doRun(t *testing.T) {
 					config.Project{
 						Dist:        t.TempDir(),
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Directory:   "scoops",
+								Description: "A run pipe test formula",
+								Homepage:    "https://github.com/goreleaser",
 							},
-							Folder:      "scoops",
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -215,8 +207,25 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
-				{Name: "foo_1.0.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
+				{
+					Name:    "foo_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
+				{
+					Name:   "foo_1.0.1_windows_386.tar.gz",
+					Goos:   "windows",
+					Goarch: "386",
+					Path:   file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
 			},
 			shouldNotErr,
 			shouldNotErr,
@@ -233,56 +242,20 @@ func Test_doRun(t *testing.T) {
 					config.Project{
 						ProjectName: "git-run-pipe",
 						Dist:        t.TempDir(),
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Name:   "test",
-								Branch: "main",
-								Git: config.GitRepoRef{
-									URL:        testlib.GitMakeBareRepository(t),
-									PrivateKey: testlib.MakeNewSSHKey(t, ""),
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Name:   "test",
+									Branch: "main",
+									Git: config.GitRepoRef{
+										URL:        testlib.GitMakeBareRepository(t),
+										PrivateKey: testlib.MakeNewSSHKey(t, ""),
+									},
 								},
+								Directory:   "scoops",
+								Description: "A run pipe test formula",
+								Homepage:    "https://github.com/goreleaser",
 							},
-							Folder:      "scoops",
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
-						},
-					},
-					testctx.GitHubTokenType,
-					testctx.WithCurrentTag("v1.0.1"),
-					testctx.WithVersion("1.0.1"),
-				),
-				client.NewMock(),
-			},
-			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
-				{Name: "foo_1.0.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
-			},
-			shouldNotErr,
-			shouldNotErr,
-			func(tb testing.TB, a args) {
-				tb.Helper()
-				content := testlib.CatFileFromBareRepositoryOnBranch(
-					tb,
-					a.ctx.Config.Scoop.Repository.Git.URL,
-					a.ctx.Config.Scoop.Repository.Branch,
-					"scoops/git-run-pipe.json",
-				)
-				golden.RequireEqualJSON(tb, content)
-			},
-		},
-		{
-			"wrap in directory",
-			args{
-				testctx.NewWithCfg(
-					config.Project{
-						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
-							},
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -298,8 +271,8 @@ func Test_doRun(t *testing.T) {
 					Goarch:  "amd64",
 					Goamd64: "v1",
 					Path:    file,
-					Extra: map[string]interface{}{
-						"Wrap": "foo_1.0.1_windows_amd64",
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
 					},
 				},
 				{
@@ -307,8 +280,67 @@ func Test_doRun(t *testing.T) {
 					Goos:   "windows",
 					Goarch: "386",
 					Path:   file,
-					Extra: map[string]interface{}{
-						"Wrap": "foo_1.0.1_windows_386",
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
+			},
+			shouldNotErr,
+			shouldNotErr,
+			func(tb testing.TB, a args) {
+				tb.Helper()
+				content := testlib.CatFileFromBareRepositoryOnBranch(
+					tb,
+					a.ctx.Config.Scoops[0].Repository.Git.URL,
+					a.ctx.Config.Scoops[0].Repository.Branch,
+					"scoops/git-run-pipe.json",
+				)
+				golden.RequireEqualJSON(tb, content)
+			},
+		},
+		{
+			"wrap in directory",
+			args{
+				testctx.NewWithCfg(
+					config.Project{
+						ProjectName: "run-pipe",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Description: "A run pipe test formula",
+								Homepage:    "https://github.com/goreleaser",
+							},
+						},
+					},
+					testctx.GitHubTokenType,
+					testctx.WithCurrentTag("v1.0.1"),
+					testctx.WithVersion("1.0.1"),
+				),
+				client.NewMock(),
+			},
+			[]artifact.Artifact{
+				{
+					Name:    "foo_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraWrappedIn: "foo_1.0.1_windows_amd64",
+						artifact.ExtraBinaries:  []string{"foo"},
+					},
+				},
+				{
+					Name:   "foo_1.0.1_windows_386.tar.gz",
+					Goos:   "windows",
+					Goarch: "386",
+					Path:   file,
+					Extra: map[string]any{
+						artifact.ExtraWrappedIn: "foo_1.0.1_windows_386",
+						artifact.ExtraBinaries:  []string{"foo"},
 					},
 				},
 			},
@@ -323,13 +355,15 @@ func Test_doRun(t *testing.T) {
 					config.Project{
 						GitHubURLs:  config.GitHubURLs{Download: "https://api.custom.github.enterprise.com"},
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Description: "A run pipe test formula",
+								Homepage:    "https://github.com/goreleaser",
 							},
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -339,8 +373,25 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
-				{Name: "foo_1.0.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
+				{
+					Name:    "foo_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
+				{
+					Name:   "foo_1.0.1_windows_386.tar.gz",
+					Goos:   "windows",
+					Goarch: "386",
+					Path:   file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
 			},
 			shouldNotErr,
 			shouldNotErr,
@@ -355,13 +406,15 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Description: "A run pipe test formula",
+								Homepage:    "https://gitlab.com/goreleaser",
 							},
-							Description: "A run pipe test formula",
-							Homepage:    "https://gitlab.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -377,12 +430,18 @@ func Test_doRun(t *testing.T) {
 					Goarch:  "amd64",
 					Goamd64: "v1",
 					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
 				},
 				{
 					Name:   "foo_1.0.1_windows_386.tar.gz",
 					Goos:   "windows",
 					Goarch: "386",
 					Path:   file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
 				},
 			},
 			shouldNotErr,
@@ -396,13 +455,15 @@ func Test_doRun(t *testing.T) {
 					config.Project{
 						GitHubURLs:  config.GitHubURLs{Download: "https://api.custom.gitlab.enterprise.com"},
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Description: "A run pipe test formula",
+								Homepage:    "https://gitlab.com/goreleaser",
 							},
-							Description: "A run pipe test formula",
-							Homepage:    "https://gitlab.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -418,12 +479,18 @@ func Test_doRun(t *testing.T) {
 					Goarch:  "amd64",
 					Goamd64: "v1",
 					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
 				},
 				{
 					Name:   "foo_1.0.1_windows_386.tar.gz",
 					Goos:   "windows",
 					Goarch: "386",
 					Path:   file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
 				},
 			},
 			shouldNotErr,
@@ -436,13 +503,15 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Description: "A run pipe test formula",
+								Homepage:    "https://github.com/goreleaser",
 							},
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -462,14 +531,16 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							SkipUpload: "auto",
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								SkipUpload: "auto",
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Description: "A run pipe test formula",
+								Homepage:    "https://github.com/goreleaser",
 							},
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -480,8 +551,25 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
-				{Name: "foo_1.0.1-pre.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
+				{
+					Name:    "foo_1.0.1-pre.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
+				{
+					Name:   "foo_1.0.1-pre.1_windows_386.tar.gz",
+					Goos:   "windows",
+					Goarch: "386",
+					Path:   file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
 			},
 			shouldNotErr,
 			shouldErr("release is prerelease"),
@@ -493,14 +581,16 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							SkipUpload: "true",
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								SkipUpload: "true",
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Description: "A run pipe test formula",
+								Homepage:    "https://github.com/goreleaser",
 							},
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -510,8 +600,25 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
-				{Name: "foo_1.0.1-pre.1_windows_386.tar.gz", Goos: "windows", Goarch: "386", Path: file},
+				{
+					Name:    "foo_1.0.1-pre.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
+				{
+					Name:   "foo_1.0.1-pre.1_windows_386.tar.gz",
+					Goos:   "windows",
+					Goarch: "386",
+					Path:   file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
 			},
 			shouldNotErr,
 			shouldErr("scoop.skip_upload is true"),
@@ -523,13 +630,15 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Description: "A run pipe test formula",
+								Homepage:    "https://github.com/goreleaser",
 							},
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -549,12 +658,14 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Name: "{{.Nope}}",
 							},
-							Name: "{{.Nope}}",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -576,12 +687,14 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Description: "{{.Nope}}",
 							},
-							Description: "{{.Nope}}",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -603,12 +716,14 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								Homepage: "{{.Nope}}",
 							},
-							Homepage: "{{.Nope}}",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -630,12 +745,14 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "test",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "test",
+									Name:  "test",
+								},
+								SkipUpload: "{{.Nope}}",
 							},
-							SkipUpload: "{{.Nope}}",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -657,14 +774,16 @@ func Test_doRun(t *testing.T) {
 				testctx.NewWithCfg(
 					config.Project{
 						ProjectName: "run-pipe",
-						Scoop: config.Scoop{
-							Repository: config.RepoRef{
-								Owner: "{{ .Env.aaaaaa }}",
-								Name:  "test",
+						Scoops: []config.Scoop{
+							{
+								Repository: config.RepoRef{
+									Owner: "{{ .Env.aaaaaa }}",
+									Name:  "test",
+								},
+								Directory:   "scoops",
+								Description: "A run pipe test formula",
+								Homepage:    "https://github.com/goreleaser",
 							},
-							Folder:      "scoops",
-							Description: "A run pipe test formula",
-							Homepage:    "https://github.com/goreleaser",
 						},
 					},
 					testctx.GitHubTokenType,
@@ -674,7 +793,16 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1-pre.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
+				{
+					Name:    "foo_1.0.1-pre.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
 			},
 			testlib.RequireTemplateError,
 			shouldNotErr,
@@ -693,7 +821,7 @@ func Test_doRun(t *testing.T) {
 								Name:   "{{ .Env.FOO }}",
 								Branch: "{{ .Env.BRANCH }}",
 							},
-							Folder:      "scoops",
+							Directory:   "scoops",
 							Description: "A run pipe test formula",
 							Homepage:    "https://github.com/goreleaser",
 						}},
@@ -705,7 +833,16 @@ func Test_doRun(t *testing.T) {
 				client.NewMock(),
 			},
 			[]artifact.Artifact{
-				{Name: "foo_1.0.1_windows_amd64.tar.gz", Goos: "windows", Goarch: "amd64", Goamd64: "v1", Path: file},
+				{
+					Name:    "foo_1.0.1_windows_amd64.tar.gz",
+					Goos:    "windows",
+					Goarch:  "amd64",
+					Goamd64: "v1",
+					Path:    file,
+					Extra: map[string]any{
+						artifact.ExtraBinaries: []string{"foo"},
+					},
+				},
 			},
 			shouldNotErr,
 			shouldNotErr,
@@ -720,7 +857,6 @@ func Test_doRun(t *testing.T) {
 			ctx := tt.args.ctx
 			ctx.Config.Dist = t.TempDir()
 			for _, a := range tt.artifacts {
-				a := a
 				a.Type = artifact.UploadableArchive
 				ctx.Artifacts.Add(&a)
 			}
@@ -735,10 +871,10 @@ func Test_doRun(t *testing.T) {
 }
 
 func TestRunPipePullRequest(t *testing.T) {
-	folder := t.TempDir()
+	directory := t.TempDir()
 	ctx := testctx.NewWithCfg(
 		config.Project{
-			Dist:        folder,
+			Dist:        directory,
 			ProjectName: "foo",
 			Scoops: []config.Scoop{{
 				Name:        "{{.Env.FOO}}",
@@ -758,17 +894,17 @@ func TestRunPipePullRequest(t *testing.T) {
 		testctx.WithCurrentTag("v1.2.1"),
 		testctx.WithEnv(map[string]string{"FOO": "foobar"}),
 	)
-	path := filepath.Join(folder, "dist/foo_windows_amd64/foo.exe")
+	path := filepath.Join(directory, "dist/foo_windows_amd64/foo.exe")
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:   "foo_windows_amd64.tar.gz",
 		Path:   path,
 		Goos:   "windows",
 		Goarch: "amd64",
 		Type:   artifact.UploadableArchive,
-		Extra: map[string]interface{}{
-			artifact.ExtraID:     "foo",
-			artifact.ExtraFormat: "tar.gz",
-			artifact.ExtraBinary: "foo",
+		Extra: map[string]any{
+			artifact.ExtraID:       "foo",
+			artifact.ExtraFormat:   "tar.gz",
+			artifact.ExtraBinaries: []string{"foo"},
 		},
 	})
 
@@ -787,8 +923,8 @@ func TestRunPipePullRequest(t *testing.T) {
 }
 
 func Test_buildManifest(t *testing.T) {
-	folder := t.TempDir()
-	file := filepath.Join(folder, "archive")
+	directory := t.TempDir()
+	file := filepath.Join(directory, "archive")
 	require.NoError(t, os.WriteFile(file, []byte("lorem ipsum"), 0o644))
 
 	tests := []struct {
@@ -809,14 +945,16 @@ func Test_buildManifest(t *testing.T) {
 							Name:  "test",
 						},
 					},
-					Scoop: config.Scoop{
-						Repository: config.RepoRef{
-							Owner: "test",
-							Name:  "test",
+					Scoops: []config.Scoop{
+						{
+							Repository: config.RepoRef{
+								Owner: "test",
+								Name:  "test",
+							},
+							Description: "A run pipe test formula",
+							Homepage:    "https://github.com/goreleaser",
+							Persist:     []string{"data", "config", "test.ini"},
 						},
-						Description: "A run pipe test formula",
-						Homepage:    "https://github.com/goreleaser",
-						Persist:     []string{"data", "config", "test.ini"},
 					},
 				},
 				testctx.GitHubTokenType,
@@ -838,16 +976,18 @@ func Test_buildManifest(t *testing.T) {
 							Name:  "test",
 						},
 					},
-					Scoop: config.Scoop{
-						Repository: config.RepoRef{
-							Owner: "test",
-							Name:  "test",
+					Scoops: []config.Scoop{
+						{
+							Repository: config.RepoRef{
+								Owner: "test",
+								Name:  "test",
+							},
+							Description: "A run pipe test formula",
+							Homepage:    "https://github.com/goreleaser",
+							Persist:     []string{"data", "config", "test.ini"},
+							PreInstall:  []string{"Write-Host 'Running preinstall command'"},
+							PostInstall: []string{"Write-Host 'Running postinstall command'"},
 						},
-						Description: "A run pipe test formula",
-						Homepage:    "https://github.com/goreleaser",
-						Persist:     []string{"data", "config", "test.ini"},
-						PreInstall:  []string{"Write-Host 'Running preinstall command'"},
-						PostInstall: []string{"Write-Host 'Running postinstall command'"},
 					},
 				},
 				testctx.GitHubTokenType,
@@ -863,16 +1003,18 @@ func Test_buildManifest(t *testing.T) {
 						Download: "https://github.com",
 					},
 					ProjectName: "run-pipe",
-					Scoop: config.Scoop{
-						Repository: config.RepoRef{
-							Owner: "test",
-							Name:  "test",
+					Scoops: []config.Scoop{
+						{
+							Repository: config.RepoRef{
+								Owner: "test",
+								Name:  "test",
+							},
+							Description:           "A run pipe test formula",
+							Homepage:              "https://github.com/goreleaser",
+							URLTemplate:           "http://github.mycompany.com/foo/bar/{{ .Tag }}/{{ .ArtifactName }}",
+							CommitMessageTemplate: "chore(scoop): update {{ .ProjectName }} version {{ .Tag }}",
+							Persist:               []string{"data.cfg", "etc"},
 						},
-						Description:           "A run pipe test formula",
-						Homepage:              "https://github.com/goreleaser",
-						URLTemplate:           "http://github.mycompany.com/foo/bar/{{ .Tag }}/{{ .ArtifactName }}",
-						CommitMessageTemplate: "chore(scoop): update {{ .ProjectName }} version {{ .Tag }}",
-						Persist:               []string{"data.cfg", "etc"},
 					},
 				},
 				testctx.WithCurrentTag("v1.0.1"),
@@ -888,16 +1030,18 @@ func Test_buildManifest(t *testing.T) {
 						Download: "https://gitlab.com",
 					},
 					ProjectName: "run-pipe",
-					Scoop: config.Scoop{
-						Repository: config.RepoRef{
-							Owner: "test",
-							Name:  "test",
+					Scoops: []config.Scoop{
+						{
+							Repository: config.RepoRef{
+								Owner: "test",
+								Name:  "test",
+							},
+							Description:           "A run pipe test formula",
+							Homepage:              "https://gitlab.com/goreleaser",
+							URLTemplate:           "http://gitlab.mycompany.com/foo/bar/-/releases/{{ .Tag }}/downloads/{{ .ArtifactName }}",
+							CommitMessageTemplate: "chore(scoop): update {{ .ProjectName }} version {{ .Tag }}",
+							Persist:               []string{"data.cfg", "etc"},
 						},
-						Description:           "A run pipe test formula",
-						Homepage:              "https://gitlab.com/goreleaser",
-						URLTemplate:           "http://gitlab.mycompany.com/foo/bar/-/releases/{{ .Tag }}/downloads/{{ .ArtifactName }}",
-						CommitMessageTemplate: "chore(scoop): update {{ .ProjectName }} version {{ .Tag }}",
-						Persist:               []string{"data.cfg", "etc"},
 					},
 				},
 				testctx.GitHubTokenType,
@@ -924,7 +1068,7 @@ func Test_buildManifest(t *testing.T) {
 					Goarch:  "amd64",
 					Goamd64: "v1",
 					Path:    file,
-					Extra: map[string]interface{}{
+					Extra: map[string]any{
 						artifact.ExtraBinaries: []string{
 							"foo.exe",
 							"bar.exe",
@@ -936,7 +1080,7 @@ func Test_buildManifest(t *testing.T) {
 					Goos:   "windows",
 					Goarch: "arm",
 					Path:   file,
-					Extra: map[string]interface{}{
+					Extra: map[string]any{
 						artifact.ExtraBinaries: []string{
 							"foo.exe",
 							"bar.exe",
@@ -948,7 +1092,7 @@ func Test_buildManifest(t *testing.T) {
 					Goos:   "windows",
 					Goarch: "arm64",
 					Path:   file,
-					Extra: map[string]interface{}{
+					Extra: map[string]any{
 						artifact.ExtraBinaries: []string{
 							"foo.exe",
 							"bar.exe",
@@ -960,7 +1104,7 @@ func Test_buildManifest(t *testing.T) {
 					Goos:   "windows",
 					Goarch: "386",
 					Path:   file,
-					Extra: map[string]interface{}{
+					Extra: map[string]any{
 						artifact.ExtraBinaries: []string{
 							"foo.exe",
 							"bar.exe",
@@ -978,26 +1122,28 @@ func Test_buildManifest(t *testing.T) {
 	}
 }
 
-func getScoopPipeSkipCtx(folder string) (*context.Context, string) {
+func getScoopPipeSkipCtx(directory string) (*context.Context, string) {
 	ctx := testctx.NewWithCfg(
 		config.Project{
-			Dist:        folder,
+			Dist:        directory,
 			ProjectName: "run-pipe",
-			Scoop: config.Scoop{
-				Repository: config.RepoRef{
-					Owner: "test",
-					Name:  "test",
+			Scoops: []config.Scoop{
+				{
+					Repository: config.RepoRef{
+						Owner: "test",
+						Name:  "test",
+					},
+					Description: "A run pipe test formula",
+					Homepage:    "https://github.com/goreleaser",
+					Name:        "run-pipe",
 				},
-				Description: "A run pipe test formula",
-				Homepage:    "https://github.com/goreleaser",
-				Name:        "run-pipe",
 			},
 		},
 		testctx.WithCurrentTag("v1.0.1"),
 		testctx.WithVersion("1.0.1"),
 	)
 
-	path := filepath.Join(folder, "bin.tar.gz")
+	path := filepath.Join(directory, "bin.tar.gz")
 
 	ctx.Artifacts.Add(&artifact.Artifact{
 		Name:    "bin.tar.gz",
@@ -1006,9 +1152,10 @@ func getScoopPipeSkipCtx(folder string) (*context.Context, string) {
 		Goarch:  "amd64",
 		Goamd64: "v1",
 		Type:    artifact.UploadableArchive,
-		Extra: map[string]interface{}{
-			artifact.ExtraID:     "foo",
-			artifact.ExtraFormat: "tar.gz",
+		Extra: map[string]any{
+			artifact.ExtraID:       "foo",
+			artifact.ExtraFormat:   "tar.gz",
+			artifact.ExtraBinaries: []string{"foo"},
 		},
 	})
 	ctx.Artifacts.Add(&artifact.Artifact{
@@ -1018,9 +1165,10 @@ func getScoopPipeSkipCtx(folder string) (*context.Context, string) {
 		Goarch:  "amd64",
 		Goamd64: "v3",
 		Type:    artifact.UploadableArchive,
-		Extra: map[string]interface{}{
-			artifact.ExtraID:     "foo",
-			artifact.ExtraFormat: "tar.gz",
+		Extra: map[string]any{
+			artifact.ExtraID:       "foo",
+			artifact.ExtraFormat:   "tar.gz",
+			artifact.ExtraBinaries: []string{"foo"},
 		},
 	})
 
@@ -1028,9 +1176,9 @@ func getScoopPipeSkipCtx(folder string) (*context.Context, string) {
 }
 
 func TestRunPipeScoopWithSkipUpload(t *testing.T) {
-	folder := t.TempDir()
-	ctx, path := getScoopPipeSkipCtx(folder)
-	ctx.Config.Scoop.SkipUpload = "true"
+	directory := t.TempDir()
+	ctx, path := getScoopPipeSkipCtx(directory)
+	ctx.Config.Scoops[0].SkipUpload = "true"
 
 	f, err := os.Create(path)
 	require.NoError(t, err)
@@ -1041,14 +1189,14 @@ func TestRunPipeScoopWithSkipUpload(t *testing.T) {
 	require.NoError(t, runAll(ctx, cli))
 	require.EqualError(t, publishAll(ctx, cli), `scoop.skip_upload is true`)
 
-	distFile := filepath.Join(folder, "scoop", ctx.Config.Scoop.Name+".json")
+	distFile := filepath.Join(directory, "scoop", ctx.Config.Scoops[0].Name+".json")
 	_, err = os.Stat(distFile)
 	require.NoError(t, err, "file should exist: "+distFile)
 }
 
 func TestWrapInDirectory(t *testing.T) {
-	folder := t.TempDir()
-	file := filepath.Join(folder, "archive")
+	directory := t.TempDir()
+	file := filepath.Join(directory, "archive")
 	require.NoError(t, os.WriteFile(file, []byte("lorem ipsum"), 0o644))
 
 	ctx := testctx.NewWithCfg(
@@ -1084,7 +1232,7 @@ func TestWrapInDirectory(t *testing.T) {
 			Goarch:  "amd64",
 			Goamd64: "v1",
 			Path:    file,
-			Extra: map[string]interface{}{
+			Extra: map[string]any{
 				artifact.ExtraWrappedIn: "foo_1.0.1_windows_amd64",
 				artifact.ExtraBinaries: []string{
 					"foo.exe",
@@ -1106,9 +1254,11 @@ func TestSkip(t *testing.T) {
 	})
 	t.Run("skip flag", func(t *testing.T) {
 		ctx := testctx.NewWithCfg(config.Project{
-			Scoop: config.Scoop{
-				Repository: config.RepoRef{
-					Name: "a",
+			Scoops: []config.Scoop{
+				{
+					Repository: config.RepoRef{
+						Name: "a",
+					},
 				},
 			},
 		}, testctx.Skip(skips.Scoop))
@@ -1116,9 +1266,11 @@ func TestSkip(t *testing.T) {
 	})
 	t.Run("dont skip", func(t *testing.T) {
 		ctx := testctx.NewWithCfg(config.Project{
-			Scoop: config.Scoop{
-				Repository: config.RepoRef{
-					Name: "a",
+			Scoops: []config.Scoop{
+				{
+					Repository: config.RepoRef{
+						Name: "a",
+					},
 				},
 			},
 		})
