@@ -1,13 +1,16 @@
+// Package sign handles signing artifacts.
 package sign
 
 import (
 	"bytes"
 	"fmt"
 	"io"
+	"maps"
 	"os"
 	"os/exec"
 	"path/filepath"
 	"strings"
+	"sync"
 
 	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
@@ -44,17 +47,21 @@ const defaultGpg = "gpg"
 
 // Default sets the Pipes defaults.
 func (Pipe) Default(ctx *context.Context) error {
-	gpgPath, _ := git.Clean(git.Run(ctx, "config", "gpg.program"))
-	if gpgPath == "" {
-		gpgPath = defaultGpg
-	}
+	gpgPath := sync.OnceValue(func() string {
+		if gpg, _ := git.Clean(
+			git.Run(ctx, "config", "gpg.program"),
+		); gpg != "" {
+			return gpg
+		}
+		return defaultGpg
+	})
 
 	ids := ids.New("signs")
 	for i := range ctx.Config.Signs {
 		cfg := &ctx.Config.Signs[i]
 		if cfg.Cmd == "" {
 			// gpgPath is either "gpg" (default) or the user's git config gpg.program value
-			cfg.Cmd = gpgPath
+			cfg.Cmd = gpgPath()
 		}
 		if cfg.Signature == "" {
 			cfg.Signature = "${artifact}.sig"
@@ -182,9 +189,7 @@ func signone(ctx *context.Context, cfg config.Sign, art *artifact.Artifact) ([]*
 		return nil, fmt.Errorf("sign failed: %s: %w", art.Name, err)
 	}
 
-	for k, v := range context.ToEnv(tmplEnv) {
-		env[k] = v
-	}
+	maps.Copy(env, context.ToEnv(tmplEnv))
 
 	name, err := tmplPath(ctx, env, art, cfg.Signature)
 	if err != nil {
@@ -255,15 +260,21 @@ func signone(ctx *context.Context, cfg config.Sign, art *artifact.Artifact) ([]*
 
 	// re-execute template results, using artifact desc as artifact so they eval to the actual needed file desc.
 	env["artifact"] = art.Name
-	name, _ = tmpl.New(ctx).WithEnv(env).Apply(expand(cfg.Signature, env))   // could never error as it passed the previous check
-	cert, _ = tmpl.New(ctx).WithEnv(env).Apply(expand(cfg.Certificate, env)) // could never error as it passed the previous check
+	name, err = tmpl.New(ctx).WithArtifact(art).WithEnv(env).Apply(expand(cfg.Signature, env))
+	if err != nil {
+		return nil, fmt.Errorf("sign failed: %s: %w", art.Name, err)
+	}
+	cert, err = tmpl.New(ctx).WithArtifact(art).WithEnv(env).Apply(expand(cfg.Certificate, env))
+	if err != nil {
+		return nil, fmt.Errorf("sign failed: %s: %w", art.Name, err)
+	}
 
 	if cfg.Signature != "" {
 		result = append(result, &artifact.Artifact{
 			Type: artifact.Signature,
 			Name: name,
 			Path: env["signature"],
-			Extra: map[string]interface{}{
+			Extra: map[string]any{
 				artifact.ExtraID: cfg.ID,
 			},
 		})
@@ -274,7 +285,7 @@ func signone(ctx *context.Context, cfg config.Sign, art *artifact.Artifact) ([]*
 			Type: artifact.Certificate,
 			Name: cert,
 			Path: env["certificate"],
-			Extra: map[string]interface{}{
+			Extra: map[string]any{
 				artifact.ExtraID: cfg.ID,
 			},
 		})
