@@ -3,20 +3,21 @@ package sign
 import (
 	"fmt"
 
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/ids"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/semerrgroup"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/ids"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/semerrgroup"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
-// Pipe that signs docker images and manifests.
+// DockerPipe that signs docker images and manifests.
 type DockerPipe struct{}
 
 func (DockerPipe) String() string { return "signing docker images" }
 
 func (DockerPipe) Skip(ctx *context.Context) bool {
-	return ctx.SkipSign || len(ctx.Config.DockerSigns) == 0
+	return skips.Any(ctx, skips.Sign) || len(ctx.Config.DockerSigns) == 0
 }
 
 func (DockerPipe) Dependencies(ctx *context.Context) []string {
