@@ -572,7 +572,7 @@ func testSign(
 		Name: "artifact1",
 		Path: filepath.Join(tmpdir, "artifact1"),
 		Type: artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID: "foo",
 		},
 	})
@@ -580,7 +580,7 @@ func testSign(
 		Name: "artifact2",
 		Path: filepath.Join(tmpdir, "artifact2"),
 		Type: artifact.UploadableArchive,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID: "foo3",
 		},
 	})
@@ -588,7 +588,7 @@ func testSign(
 		Name: "artifact3_1.0.0_linux_amd64",
 		Path: filepath.Join(tmpdir, "artifact3"),
 		Type: artifact.UploadableBinary,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID: "foo",
 		},
 	})
@@ -601,7 +601,7 @@ func testSign(
 		Name: "checksum2",
 		Path: filepath.Join(tmpdir, "checksum2"),
 		Type: artifact.Checksum,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			"Refresh": func() error {
 				file := filepath.Join(tmpdir, "checksum2")
 				return os.WriteFile(file, []byte("foo"), 0o644)
@@ -612,7 +612,7 @@ func testSign(
 		Name: "artifact4_1.0.0_linux_amd64",
 		Path: filepath.Join(tmpdir, "linux_amd64", "artifact4"),
 		Type: artifact.UploadableBinary,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID: "foo3",
 		},
 	})
@@ -630,7 +630,7 @@ func testSign(
 		Name: "package1.deb",
 		Path: filepath.Join(tmpdir, "package1.deb"),
 		Type: artifact.LinuxPackage,
-		Extra: map[string]interface{}{
+		Extra: map[string]any{
 			artifact.ExtraID: "foo",
 		},
 	})
