@@ -1,3 +1,4 @@
+// Package upx compresses binaries using upx.
 package upx
 
 import (
@@ -96,6 +97,7 @@ var knownExceptions = []string{
 	"AlreadyPackedException",
 	"NotCompressibleException",
 	"UnknownExecutableFormatException",
+	"IOException",
 }
 
 func findBinaries(ctx *context.Context, upx config.UPX) []*artifact.Artifact {
